SearchBlankResponse class

Response from PersonalizationSdk.searchBlank.

Contains trending/popular products and search suggestions configured for the shop.

Excluded Android-only fields: html. Excluded iOS-only fields: lastQueries, lastProducts.

Constructors

SearchBlankResponse({required List<SearchProduct> products, required List<SearchSuggest> suggests})
const
SearchBlankResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
products List<SearchProduct>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggests List<SearchSuggest>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited