ProductCountersResponse class
Response from PersonalizationSdk.getProductCounters.
Mirrors native ProductCountersResponse: per-period view/cart/purchase
counters plus trigger flags.
Constructors
- ProductCountersResponse({ProductCounter? daily, ProductCounter? now, ProductCounterTriggers? triggers})
-
const
-
ProductCountersResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- daily → ProductCounter?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- now → ProductCounter?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- triggers → ProductCounterTriggers?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited