SearchFullResponse class
Response from PersonalizationSdk.searchFull.
Excluded Android-only response fields: brands (List<Brand>), clarification,
collections, html, priceMedian, priceRanges, requestsCount, searchQuery.
Excluded iOS-only response fields: filters, industrialFilters, redirect, queries.
Constructors
-
SearchFullResponse({required List<
SearchProduct> products, required List<SearchCategory> categories, required int productsTotal, SearchPriceRange? priceRange, List<SearchLocation> ? locations}) -
const
-
SearchFullResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
categories
→ List<
SearchCategory> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locations
→ List<
SearchLocation> ? -
final
- priceRange → SearchPriceRange?
-
final
-
products
→ List<
SearchProduct> -
final
- productsTotal → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited