SearchInstantResponse class
Response from PersonalizationSdk.searchInstant.
Subset of SearchFullResponse — no priceRange (not present in Android
SearchInstantResponse). Shares the same SearchProduct, SearchCategory,
and SearchLocation models.
Excluded Android-only fields: clarification, collections, html, requestsCount, searchQuery, bookAuthor, queries. Excluded iOS-only fields: filters, industrialFilters, redirect, queries, brands.
Constructors
-
SearchInstantResponse({required List<
SearchProduct> products, required List<SearchCategory> categories, required int productsTotal, List<SearchLocation> ? locations}) -
const
-
SearchInstantResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
categories
→ List<
SearchCategory> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locations
→ List<
SearchLocation> ? -
final
-
products
→ List<
SearchProduct> -
final
- productsTotal → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited